pub struct SqliteStore { /* private fields */ }Expand description
Represents a pool of connections with an SQLite database. The pool is used to interact
concurrently with the underlying database in a safe and efficient manner.
Current table definitions can be found at store.sql migration file.
Implementations
Sourceimpl SqliteStore
impl SqliteStore
pub fn get_foreign_account_code( conn: &mut Connection, account_ids: Vec<AccountId>, ) -> Result<BTreeMap<AccountId, AccountCode>, StoreError>
Sourcepub fn get_account_vault(
conn: &Connection,
account_id: AccountId,
) -> Result<AssetVault, StoreError>
pub fn get_account_vault( conn: &Connection, account_id: AccountId, ) -> Result<AssetVault, StoreError>
Retrieves the full asset vault for a specific account.
Sourcepub fn get_account_storage(
conn: &Connection,
account_id: AccountId,
filter: &AccountStorageFilter,
) -> Result<AccountStorage, StoreError>
pub fn get_account_storage( conn: &Connection, account_id: AccountId, filter: &AccountStorageFilter, ) -> Result<AccountStorage, StoreError>
Retrieves the full storage for a specific account.
pub fn upsert_foreign_account_code( conn: &mut Connection, account_id: AccountId, code: &AccountCode, ) -> Result<(), StoreError>
Sourcepub fn prune_account_history(
conn: &mut Connection,
account_id: AccountId,
up_to_nonce: Felt,
) -> Result<usize, StoreError>
pub fn prune_account_history( conn: &mut Connection, account_id: AccountId, up_to_nonce: Felt, ) -> Result<usize, StoreError>
Prunes historical account states for a single account up to the given nonce.
Deletes all historical entries with replaced_at_nonce <= up_to_nonce
(see DESIGN.md for why this threshold is safe), then removes any account
code that was only referenced by the deleted headers.
Sourceimpl SqliteStore
impl SqliteStore
pub fn insert_partial_blockchain_nodes( conn: &mut Connection, nodes: &[(InOrderIndex, Word)], ) -> Result<(), StoreError>
Sourcepub fn prune_irrelevant_blocks(
conn: &mut Connection,
blocks_to_untrack: &[BlockNumber],
node_indices_to_remove: &[InOrderIndex],
) -> Result<(), StoreError>
pub fn prune_irrelevant_blocks( conn: &mut Connection, blocks_to_untrack: &[BlockNumber], node_indices_to_remove: &[InOrderIndex], ) -> Result<(), StoreError>
Prunes irrelevant block data from the store.
This performs three operations in a single transaction:
- Deletes MMR authentication nodes at the given
node_indices. - Sets
has_client_notes = falseforblocks_to_untrack. - Deletes block headers with
has_client_notes = falsethat are not the genesis or sync-height block.
Sourceimpl SqliteStore
impl SqliteStore
Sourcepub fn get_transactions(
conn: &mut Connection,
filter: &TransactionFilter,
) -> Result<Vec<TransactionRecord>, StoreError>
pub fn get_transactions( conn: &mut Connection, filter: &TransactionFilter, ) -> Result<Vec<TransactionRecord>, StoreError>
Retrieves tracked transactions, filtered by TransactionFilter.
Sourcepub fn apply_transaction(
conn: &mut Connection,
smt_forest: &Arc<RwLock<AccountSmtForest>>,
tx_update: &TransactionStoreUpdate,
) -> Result<(), StoreError>
pub fn apply_transaction( conn: &mut Connection, smt_forest: &Arc<RwLock<AccountSmtForest>>, tx_update: &TransactionStoreUpdate, ) -> Result<(), StoreError>
Inserts a transaction and updates the current state based on the tx_result changes.
SQL writes and AccountSmtForest mutations are committed atomically: on any error
(including commit failure) the rusqlite transaction is rolled back and the in-memory
forest is left unchanged.
Sourcepub fn apply_transaction_batch(
conn: &mut Connection,
smt_forest: &Arc<RwLock<AccountSmtForest>>,
tx_updates: &[TransactionStoreUpdate],
) -> Result<(), StoreError>
pub fn apply_transaction_batch( conn: &mut Connection, smt_forest: &Arc<RwLock<AccountSmtForest>>, tx_updates: &[TransactionStoreUpdate], ) -> Result<(), StoreError>
Applies a batch of TransactionStoreUpdates atomically. Either every update in the
slice is persisted or none are. Executes in order inside a single
rusqlite::Transaction; on any error the transaction is rolled back automatically
and the in-memory AccountSmtForest is left unchanged.
Sourceimpl SqliteStore
impl SqliteStore