SqliteStore

Struct SqliteStore 

pub struct SqliteStore { /* private fields */ }
Represents a pool of connections with an SQLite database. The pool is used to interact concurrently with the underlying database in a safe and efficient manner.

Current table definitions can be found at store.sql migration file.

Implementations

Source

impl SqliteStore

pub fn get_foreign_account_code( conn: &mut Connection, account_ids: Vec<AccountId>, ) -> Result<BTreeMap<AccountId, AccountCode>, StoreError>

pub fn get_account_vault( conn: &Connection, account_id: AccountId, ) -> Result<AssetVault, StoreError>

Retrieves the full asset vault for a specific account.

pub fn get_account_storage( conn: &Connection, account_id: AccountId, filter: &AccountStorageFilter, ) -> Result<AccountStorage, StoreError>

Retrieves the full storage for a specific account.

pub fn upsert_foreign_account_code( conn: &mut Connection, account_id: AccountId, code: &AccountCode, ) -> Result<(), StoreError>

Source

impl SqliteStore

pub fn insert_partial_blockchain_nodes( conn: &mut Connection, nodes: &[(InOrderIndex, Word)], ) -> Result<(), StoreError>

pub fn prune_irrelevant_blocks(conn: &mut Connection) -> Result<(), StoreError>

Removes block headers that do not contain any client notes and aren’t the genesis or last block.

Source

impl SqliteStore

pub fn get_transactions( conn: &mut Connection, filter: &TransactionFilter, ) -> Result<Vec<TransactionRecord>, StoreError>

Retrieves tracked transactions, filtered by TransactionFilter.

pub fn apply_transaction( conn: &mut Connection, smt_forest: &Arc<RwLock<AccountSmtForest>>, tx_update: &TransactionStoreUpdate, ) -> Result<(), StoreError>

Inserts a transaction and updates the current state based on the tx_result changes.

Source

impl SqliteStore

pub async fn new(database_filepath: PathBuf) -> Result<Self, StoreError>

Returns a new instance of Store instantiated with the specified configuration options.