pub struct SqliteStore { /* private fields */ }Expand description
Represents a pool of connections with an SQLite database. The pool is used to interact
concurrently with the underlying database in a safe and efficient manner.
Current table definitions can be found at store.sql migration file.
Implementations
Sourceimpl SqliteStore
impl SqliteStore
pub fn upsert_foreign_account_code( conn: &mut Connection, account_id: AccountId, code: &AccountCode, ) -> Result<(), StoreError>
pub fn get_foreign_account_code( conn: &mut Connection, account_ids: Vec<AccountId>, ) -> Result<BTreeMap<AccountId, AccountCode>, StoreError>
Sourcepub fn get_account_vault(
conn: &Connection,
account_id: AccountId,
) -> Result<AssetVault, StoreError>
pub fn get_account_vault( conn: &Connection, account_id: AccountId, ) -> Result<AssetVault, StoreError>
Retrieves the full asset vault for a specific account.
Sourcepub fn get_account_storage(
conn: &Connection,
account_id: AccountId,
) -> Result<AccountStorage, StoreError>
pub fn get_account_storage( conn: &Connection, account_id: AccountId, ) -> Result<AccountStorage, StoreError>
Retrieves the full storage for a specific account.
Sourceimpl SqliteStore
impl SqliteStore
pub fn insert_partial_blockchain_nodes( conn: &mut Connection, nodes: &[(InOrderIndex, Word)], ) -> Result<(), StoreError>
Sourcepub fn prune_irrelevant_blocks(conn: &mut Connection) -> Result<(), StoreError>
pub fn prune_irrelevant_blocks(conn: &mut Connection) -> Result<(), StoreError>
Removes block headers that do not contain any client notes and aren’t the genesis or last block.
Sourceimpl SqliteStore
impl SqliteStore
Sourcepub fn get_transactions(
conn: &mut Connection,
filter: &TransactionFilter,
) -> Result<Vec<TransactionRecord>, StoreError>
pub fn get_transactions( conn: &mut Connection, filter: &TransactionFilter, ) -> Result<Vec<TransactionRecord>, StoreError>
Retrieves tracked transactions, filtered by TransactionFilter.
Sourcepub fn apply_transaction(
conn: &mut Connection,
merkle_store: &Arc<RwLock<MerkleStore>>,
tx_update: &TransactionStoreUpdate,
) -> Result<(), StoreError>
pub fn apply_transaction( conn: &mut Connection, merkle_store: &Arc<RwLock<MerkleStore>>, tx_update: &TransactionStoreUpdate, ) -> Result<(), StoreError>
Inserts a transaction and updates the current state based on the tx_result changes.
Sourceimpl SqliteStore
impl SqliteStore